==> dict-1.0.0-sources.jar: com/ark/dict/ConfigMapLoader.java <==
package com.ark.dict;

import android.content.Context;
import android.content.IntentFilter;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Log;
import com.ark.net.urlconn.StringCallback;
import com.tencent.mmkv.MMKV;
import com.yanzhenjie.kalle.Kalle;
import com.yanzhenjie.kalle.simple.SimpleResponse;
import com.yanzhenjie.kalle.simple.cache.CacheMode;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public final class ConfigMapLoader {

    private static final String KEY_CONFIG = "key_val_config";
    private static final String ID_CONFIG = "key_val_id";
    private static Map<String, String> mResponseMap = new HashMap<>();
    private static ConfigBroadcastReceiver sReceive = new ConfigBroadcastReceiver();
    private Map<String, String> mParamMap = new HashMap<>();
    private ConfigBroadcastReceiver receiver;

    private ConfigMapLoader() {
        Context context = Utils.getContext();
        mParamMap.put("appid", InnerUtils.encode32MD5(context.getPackageName()));
        mParamMap.put("package_name", context.getPackageName());
        mParamMap.put("sys", "android");
        mParamMap.put("os", "android");
        mParamMap.put("channel", InnerUtils.getChannel(context));
        mParamMap.put("appver", InnerUtils.getVersionName(context));
        mParamMap.put("lan", InnerUtils.getLanguage(context));
    }

    public static ConfigMapLoader getInstance() {
        return Holder.configMapLoader;
    }

    /**
     * 添加设置响应监听
     *
     * @param context  上下文
     * @param listener 监听
     * @return ConfigMapLoader
     */
    @NonNull
    public ConfigMapLoader addOnConfigRespListener(@NonNull Context context,
            @NonNull OnConfigRespListener listener) {
        if (!mResponseMap.isEmpty()) {
            listener.onLoaded(false, this);
        } else {
            receiver = new ConfigBroadcastReceiver();
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction(context.getPackageName() + ".dict.config.ACTION");
            context.registerReceiver(receiver, intentFilter);
            sReceive.addOnConfigRespListener(listener);
        }
        return this;
    }

    /**
     * 移除所有响应监听
     *
     * @param context 上下文
     */
    public void removeAllOnConfigRespListener(@NonNull Context context) {
        if (receiver != null) {
            try {
                context.unregisterReceiver(receiver);
            } catch (Exception e) {
                Log.e("logger", e.getLocalizedMessage());
            }
            receiver = null;
        }
        sReceive.removeAllOnConfigRespListener();
    }

    /**
     * 获取键值对信息
     *
     * @return Map
     */
    @NonNull
    public Map<String, String> getResponseMap() {
        if (mResponseMap.isEmpty()) {
            String json = loadFromCache();
            try {
                Log.w("logger", "使用离线配置");
                mResponseMap = loadJsonToMap(json);
            } catch (Exception e) {
                Log.e("logger", e.getLocalizedMessage());
            }
        }
        return mResponseMap;
    }

    /**
     * 从rawStr中获取键值对
     *
     * @param json rawStr
     * @return Map
     * @throws Exception 解析异常
     */
    @NonNull
    private Map<String, String> loadJsonToMap(String json) throws Exception {
        Map<String, String> mResponseMap = new HashMap<>();
        if (!TextUtils.isEmpty(json)) {
            JSONObject responseObject = new JSONObject(json);
            JSONObject resObject = responseObject.optJSONObject("res");
            JSONObject params = resObject.optJSONObject("params");
            JSONObject kvObj = params == null ? resObject : params;
            Iterator<String> iterator = kvObj.keys();
            String key;
            String value;
            while (iterator.hasNext()) {
                key = iterator.next();
                value = kvObj.optString(key);
                mResponseMap.put(key, value);
            }
        }
        return mResponseMap;
    }

    /**
     * 从缓存键值对中取出配置
     *
     * @return rawStr
     */
    @NonNull
    private String loadFromCache() {
        MMKV kv = MMKV.mmkvWithID(ID_CONFIG, MMKV.MULTI_PROCESS_MODE);
        String local = kv.decodeString(KEY_CONFIG, "");
        Log.i("logger", "local-->" + local);
        return local;
    }

    /**
     * 请求配置
     *
     * @param byUser 是否主动请求,初始化时会有一个默认请求
     */
    void request(final boolean byUser) {
        Kalle.get(getRequestUrl())
                .cacheKey(KEY_CONFIG)
                .cacheMode(CacheMode.NETWORK_NO_THEN_READ_CACHE)
                .perform(new StringCallback<String>(Utils.getContext()) {
                    @Override
                    public void onResponse(SimpleResponse<String, String> response) {
                        String json = null;
                        if (response.isSucceed()) {
                            json = response.succeed();
                            Log.w("logger", "在线配置请求成功:" + json);
                            MMKV kv = MMKV.mmkvWithID(ID_CONFIG, MMKV.MULTI_PROCESS_MODE);
                            kv.encode(KEY_CONFIG, json);
                        } else {
                            Log.w("logger", "在线配置请求失败:" + response.failed());
                        }
                        if (TextUtils.isEmpty(json)) {
                            json = loadFromCache();
                        }
                        try {
                            mResponseMap = loadJsonToMap(json);
                        } catch (Exception e) {
                            Log.e("logger", e.getLocalizedMessage());
                        }
                        InnerUtils.sendConfigResp(Utils.getContext(), byUser);
                    }
                });
    }

    /**
     * 主动请求
     */
    public void request() {
        request(true);
    }

    /**
     * 强制刷新
     *
     * @param enabled 开启强制刷新服务器缓存
     * @return ConfigMapLoader
     */
    @NonNull
    public ConfigMapLoader enableRefresh(boolean enabled) {
        if (enabled) {
            mParamMap.put("currenttime", String.valueOf(System.currentTimeMillis()));
        }
        return this;
    }

    /**
     * 是否是老后台,兼容不同的请求以及结果
     *
     * @return 是否是老后台
     */
    public boolean isOldServer() {
        String pkName = Utils.getContext().getPackageName();
        return TextUtils.equals(pkName, "com.emojifair.emoji")
                || TextUtils.equals(pkName, "com.emojifair.emoji")
                || TextUtils.equals(pkName, "com.novv.resshare")
                || TextUtils.equals(pkName, "com.androidesk")
                || TextUtils.equals(pkName, "com.lovebizhi.wallpaper")
                || TextUtils.equals(pkName, "com.androidesk.livewallpaper");
    }

    /**
     * 获取请求的url
     *
     * @return url
     */
    @NonNull
    public String getRequestUrl() {
        final StringBuilder builderUrl = new StringBuilder();
        if (isOldServer()) {
            builderUrl.append("http://service.kv.dandanjiang.tv/online/params");
        } else {
            builderUrl.append("http://service.kv.dandanjiang.tv/remote");
        }
        if (mParamMap.size() != 0) {
            builderUrl.append("?");
            for (Object object : mParamMap.entrySet()) {
                Map.Entry entry = (Map.Entry) object;
                String key = (String) entry.getKey();
                String val = (String) entry.getValue();
                builderUrl.append(key);
                builderUrl.append("=");
                builderUrl.append(val);
                builderUrl.append("&");
            }
            builderUrl.deleteCharAt(builderUrl.length() - 1);
        }
        return builderUrl.toString();
    }

    private static class Holder {

        private static ConfigMapLoader configMapLoader = new ConfigMapLoader();
    }
}

==> dict-1.0.1-sources.jar: com/ark/dict/ConfigMapLoader.java <==
package com.ark.dict;

import android.content.Context;
import android.content.IntentFilter;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Log;
import com.ark.net.urlconn.StringCallback;
import com.yanzhenjie.kalle.Kalle;
import com.yanzhenjie.kalle.simple.SimpleResponse;
import com.yanzhenjie.kalle.simple.cache.CacheMode;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public final class ConfigMapLoader {

    private static final String KEY_CONFIG = "key_val_config";
    private static final String ID_CONFIG = "key_val_id";
    private static Map<String, String> mResponseMap = new HashMap<>();
    private static ConfigBroadcastReceiver sReceive = new ConfigBroadcastReceiver();
    private Map<String, String> mParamMap = new HashMap<>();
    private ConfigBroadcastReceiver receiver;

    private ConfigMapLoader() {
        Context context = Utils.getContext();
        mParamMap.put("appid", InnerUtils.encode32MD5(context.getPackageName()));
        mParamMap.put("package_name", context.getPackageName());
        mParamMap.put("sys", "android");
        mParamMap.put("os", "android");
        mParamMap.put("channel", InnerUtils.getChannel(context));
        mParamMap.put("appver", InnerUtils.getVersionName(context));
        mParamMap.put("lan", InnerUtils.getLanguage(context));
    }

    public static ConfigMapLoader getInstance() {
        return Holder.configMapLoader;
    }

    /**
     * 添加设置响应监听
     *
     * @param context  上下文
     * @param listener 监听
     * @return ConfigMapLoader
     */
    @NonNull
    public ConfigMapLoader addOnConfigRespListener(@NonNull Context context,
                                                   @NonNull OnConfigRespListener listener) {
        if (!mResponseMap.isEmpty()) {
            listener.onLoaded(false, this);
        } else {
            receiver = new ConfigBroadcastReceiver();
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction(context.getPackageName() + ".dict.config.ACTION");
            context.registerReceiver(receiver, intentFilter);
            sReceive.addOnConfigRespListener(listener);
        }
        return this;
    }

    /**
     * 移除所有响应监听
     *
     * @param context 上下文
     */
    public void removeAllOnConfigRespListener(@NonNull Context context) {
        if (receiver != null) {
            try {
                context.unregisterReceiver(receiver);
            } catch (Exception e) {
                Log.e("logger", e.getLocalizedMessage());
            }
            receiver = null;
        }
        sReceive.removeAllOnConfigRespListener();
    }

    /**
     * 获取键值对信息
     *
     * @return Map
     */
    @NonNull
    public Map<String, String> getResponseMap() {
        if (mResponseMap.isEmpty()) {
            String json = loadFromCache();
            try {
                Log.w("logger", "使用离线配置");
                mResponseMap = loadJsonToMap(json);
            } catch (Exception e) {
                Log.e("logger", e.getLocalizedMessage());
            }
        }
        return mResponseMap;
    }

    /**
     * 从rawStr中获取键值对
     *
     * @param json rawStr
     * @return Map
     * @throws Exception 解析异常
     */
    @NonNull
    private Map<String, String> loadJsonToMap(String json) throws Exception {
        Map<String, String> mResponseMap = new HashMap<>();
        if (!TextUtils.isEmpty(json)) {
            JSONObject responseObject = new JSONObject(json);
            JSONObject resObject = responseObject.optJSONObject("res");
            JSONObject params = resObject.optJSONObject("params");
            JSONObject kvObj = params == null ? resObject : params;
            Iterator<String> iterator = kvObj.keys();
            String key;
            String value;
            while (iterator.hasNext()) {
                key = iterator.next();
                value = kvObj.optString(key);
                mResponseMap.put(key, value);
            }
        }
        return mResponseMap;
    }

    /**
     * 从缓存键值对中取出配置
     *
     * @return rawStr
     */
    @NonNull
    private String loadFromCache() {
        String local = getString(KEY_CONFIG, "");
        Log.i("logger", "local-->" + local);
        return local;
    }

    /**
     * 请求配置
     *
     * @param byUser 是否主动请求,初始化时会有一个默认请求
     */
    void request(final boolean byUser) {
        Kalle.get(getRequestUrl())
                .cacheKey(KEY_CONFIG)
                .cacheMode(CacheMode.NETWORK_NO_THEN_READ_CACHE)
                .perform(new StringCallback<String>(Utils.getContext()) {
                    @Override
                    public void onResponse(SimpleResponse<String, String> response) {
                        String json = null;
                        if (response.isSucceed()) {
                            json = response.succeed();
                            saveString(KEY_CONFIG, json);
                            Log.w("logger", "在线配置请求成功:");
                        } else {
                            Log.w("logger", "在线配置请求失败:" + response.failed());
                        }
                        if (TextUtils.isEmpty(json)) {
                            json = loadFromCache();
                        }
                        try {
                            mResponseMap = loadJsonToMap(json);
                        } catch (Exception e) {
                            Log.e("logger", e.getLocalizedMessage());
                        }
                        InnerUtils.sendConfigResp(Utils.getContext(), byUser);
                    }
                });
    }

    public static void saveString(String key, String value) {
        try {
            Class.forName("com.tencent.mmkv.MMKV");
            com.tencent.mmkv.MMKV mmkv = com.tencent.mmkv.MMKV.mmkvWithID(ID_CONFIG, com.tencent.mmkv.MMKV.MULTI_PROCESS_MODE);
            mmkv.encode(key, value);
            Log.i("logger", "mmkv save String :key:" + key + ",\nvalue:" + value);
        } catch (ClassNotFoundException e) {
            Utils.getContext()
                    .getSharedPreferences(ID_CONFIG, Context.MODE_PRIVATE)
                    .edit()
                    .putString(key, value)
                    .apply();
            Log.i("logger", "SharedPreferences save String :key:" + key + ",\nvalue:" + value);
        }
    }

    public static String getString(String key, String defValue) {
        String value;
        try {
            Class.forName("com.tencent.mmkv.MMKV");
            com.tencent.mmkv.MMKV mmkv = com.tencent.mmkv.MMKV.mmkvWithID(ID_CONFIG, com.tencent.mmkv.MMKV.MULTI_PROCESS_MODE);
            value = mmkv.decodeString(key, defValue);
            Log.i("logger", "mmkv get String :key:" + key + ",\nvalue:" + value);
        } catch (ClassNotFoundException e) {
            value = Utils.getContext()
                    .getSharedPreferences(ID_CONFIG, Context.MODE_PRIVATE)
                    .getString(key, defValue);
            Log.i("logger", "SharedPreferences get String :key:" + key + ",\nvalue:" + value);
        }
        return value;
    }

    /**
     * 主动请求
     */
    public void request() {
        request(true);
    }

    /**
     * 是否是老后台,兼容不同的请求以及结果
     *
     * @return 是否是老后台
     */
    public boolean isOldServer() {
        String pkName = Utils.getContext().getPackageName();
        return TextUtils.equals(pkName, "com.emojifair.emoji")
                || TextUtils.equals(pkName, "com.emojifair.emoji")
                || TextUtils.equals(pkName, "com.novv.resshare")
                || TextUtils.equals(pkName, "com.androidesk")
                || TextUtils.equals(pkName, "com.lovebizhi.wallpaper")
                || TextUtils.equals(pkName, "com.androidesk.livewallpaper");
    }

    /**
     * 获取请求的url
     *
     * @return url
     */
    @NonNull
    public String getRequestUrl() {
        final StringBuilder builderUrl = new StringBuilder();
        if (isOldServer()) {
            builderUrl.append("http://service.kv.dandanjiang.tv/online/params");
        } else {
            builderUrl.append("http://service.kv.dandanjiang.tv/remote");
        }
        if (mParamMap.size() != 0) {
            builderUrl.append("?");
            for (Object object : mParamMap.entrySet()) {
                Map.Entry entry = (Map.Entry) object;
                String key = (String) entry.getKey();
                String val = (String) entry.getValue();
                builderUrl.append(key);
                builderUrl.append("=");
                builderUrl.append(val);
                builderUrl.append("&");
            }
            builderUrl.deleteCharAt(builderUrl.length() - 1);
        }
        return builderUrl.toString();
    }

    private static class Holder {

        private static ConfigMapLoader configMapLoader = new ConfigMapLoader();
    }
}
